pub struct Marker { /* private fields */ }Expand description
A location in a yaml document.
Implementations
Sourceimpl Marker
impl Marker
Sourcepub fn new(index: usize, line: usize, col: usize) -> Marker
pub fn new(index: usize, line: usize, col: usize) -> Marker
Create a new Marker at the given position.
Sourcepub fn with_byte_offset(self, byte_offset: Option<usize>) -> Marker
pub fn with_byte_offset(self, byte_offset: Option<usize>) -> Marker
Return a copy of the marker with the given optional byte offset.
Sourcepub fn byte_offset(&self) -> Option<usize>
pub fn byte_offset(&self) -> Option<usize>
Return the byte offset of the marker in the source, if available.